/*
 * Copyright 2018 Equilinox Mod Kit Project
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *    the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 * BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
 * SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package equilinoxmodkit.mod;


/**
 * Base class for all Equilinox Mod Kit mods. Classes extending {@code EquilinoxMod} will automatically be recognized by the Equilinox Mod Loader.<br>
 * The {@link ModInfo} annotation is required for the mod to be loaded by the Equilinox Mod Loader. Optionally {@link Dependency} can be used to
 * declare a dependency on other mods (dependency system not yet implemented!).
 *
 * @author EMK Team
 */
public abstract class EquilinoxMod {
	
	
	/**
	 * Get's called when this mod is loaded by Equilinox Mod Loader.
	 *
	 * @param pInit
	 */
	public abstract void preInit( PreInitializer pInit );
	
	/**
	 * Get's called after Equilinox has started, but before it initialized it's resources and before the game loop starts (not yet implemented!).
	 *
	 * @param init
	 */
	public abstract void init( Initializer init );
	
	
	/**
	 * @return This mod's {@code ModInfo} or {@code null} if not present.<br>
	 * Hint: <i>A {@code ModInfo} annotation should be present at all times (see {@link EquilinoxMod})!</i>
	 */
	public ModInfo getModInfo() {
		return getClass().getDeclaredAnnotation( ModInfo.class );
	}
	
	/**
	 * @return This mod's {@code Dependency} or {@code null} if not present (dependency system not yet implemented!).
	 */
	public Dependency getDependency() {
		return getClass().getDeclaredAnnotation( Dependency.class );
	}
	
	
}
